@@ -23,7 +23,7 @@
 #' Hidden arguments:
 #' Deactivate adaptive lasso by setting \code{adaptive} to \code{FALSE},
 #' activate standard lasso by setting \code{standard} to \code{TRUE},
-#' and deactivate shrinkage by setting \code{shrink} to \code{FALSE}.
+#' and activate shrinkage by setting \code{shrink} to \code{TRUE}.
 #' 
 #' @return
 #' This function returns an object of class \code{palasso}.
@@ -39,9 +39,9 @@
 #' 
 #' @references
 #' A Rauschenberger, I Ciocanea-Teodorescu, RX Menezes, MA Jonker,
-#' and MA van de Wiel (2019). "Sparse classification with paired covariates."
-#' \emph{Advances in Data Analysis and Classification}. In press.
-#' \href{https://doi.org/10.1007/s11634-019-00375-6}{doi: 10.1007/s11634-019-00375-6},
+#' and MA van de Wiel (2020). "Sparse classification with paired covariates."
+#' \emph{Advances in Data Analysis and Classification}. 14:571-588.
+#' \doi{10.1007/s11634-019-00375-6},
 #' \href{https://link.springer.com/content/pdf/10.1007/s11634-019-00375-6.pdf}{pdf},
 #' \email{armin.rauschenberger@uni.lu}
 #' 
@@ -50,7 +50,8 @@
 #' n <- 50; p <- 20
 #' y <- rbinom(n=n,size=1,prob=0.5)
 #' X <- lapply(1:2,function(x) matrix(rnorm(n*p),nrow=n,ncol=p))
-#' object <- palasso(y=y,X=X,family="binomial",standard=TRUE)
+#' object <- palasso(y=y,X=X,family="binomial") # adaptive=TRUE,standard=FALSE
+#' names(object)
 #' 
 palasso <- function(y=y,X=X,max=10,...){
     
@@ -221,7 +222,7 @@ NULL
     
     # conditional usage of CorShrink
     if(args$shrink & (!"CorShrink" %in% .packages(all.available=TRUE))){
-      warning("Install \"CorShrink\" from CRAN archive, or shrink=FALSE.",call.=FALSE)
+      warning("Install \"CorShrink\", or shrink=FALSE.",call.=FALSE)
       args$shrink <- FALSE
     }
     
